@@ -8,20 +8,23 @@
  *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #include "HotkeysDialog.hpp"
+
+#include "UserInterface/UICommon.hpp"
 #include "common.hpp"
 
 using namespace UserInterface;
 
 HotkeysDialog::HotkeysDialog(QWidget* parent, QList<HotkeySettingMapping> hotkeySettingMappings, 
-    bool isGameController, SDL_JoystickID joystickId, 
+    SDL_JoystickID joystickId, SDL_Gamepad* gamepad,
     bool filterEvents, bool removeDuplicates) : QDialog(parent, Qt::WindowSystemMenuHint | Qt::WindowTitleHint)
 {
     this->setupUi(this);
 
-    this->currentJoystickId               = joystickId;
-    this->isCurrentJoystickGameController = isGameController;
-    this->filterEventsForButtons          = filterEvents;
-    this->removeDuplicates                = removeDuplicates;
+    this->currentJoystickId        = joystickId;
+    this->currentGamepad           = gamepad;
+    this->isCurrentJoystickGamepad = (gamepad != nullptr);
+    this->filterEventsForButtons   = filterEvents;
+    this->removeDuplicates         = removeDuplicates;
 
     this->hotkeySettingMappings.append(
     {
@@ -87,7 +90,7 @@ HotkeysDialog::HotkeysDialog(QWidget* parent, QList<HotkeySettingMapping> hotkey
         for (size_t y = 0; y < givenMapping.inputTypes.size(); y++)
         {
             buttonMapping.button->AddInputData(
-                (InputType)givenMapping.inputTypes.at(y),
+                static_cast<InputType>(givenMapping.inputTypes.at(y)),
                 givenMapping.inputData.at(y),
                 givenMapping.extraInputData.at(y),
                 QString::fromStdString(givenMapping.inputText.at(y))
@@ -115,7 +118,7 @@ void HotkeysDialog::on_MainDialog_SdlEvent(SDL_Event* event)
 
             if (event->type == SDL_EVENT_GAMEPAD_BUTTON_DOWN)
             { // gamepad button
-                if (!this->isCurrentJoystickGameController &&
+                if (!this->isCurrentJoystickGamepad &&
                     this->filterEventsForButtons)
                 {
                     return;
@@ -124,11 +127,11 @@ void HotkeysDialog::on_MainDialog_SdlEvent(SDL_Event* event)
                 joystickId = event->gbutton.which;
                 inputType = InputType::GamepadButton;
                 sdlButton = event->gbutton.button;
-                sdlButtonName = SDL_GetGamepadStringForButton((SDL_GamepadButton)sdlButton);
+                sdlButtonName = UICommon::GetGamepadButtonText(this->currentGamepad, static_cast<SDL_GamepadButton>(sdlButton));
             }
             else
             { // joystick button
-                if (this->isCurrentJoystickGameController &&
+                if (this->isCurrentJoystickGamepad &&
                     this->filterEventsForButtons)
                 {
                     return;
@@ -164,7 +167,7 @@ void HotkeysDialog::on_MainDialog_SdlEvent(SDL_Event* event)
 
             if (event->type == SDL_EVENT_GAMEPAD_BUTTON_UP)
             { // gamepad button
-                if (!this->isCurrentJoystickGameController &&
+                if (!this->isCurrentJoystickGamepad &&
                     this->filterEventsForButtons)
                 {
                     return;
@@ -174,7 +177,7 @@ void HotkeysDialog::on_MainDialog_SdlEvent(SDL_Event* event)
             }
             else
             { // joystick button
-                if (this->isCurrentJoystickGameController &&
+                if (this->isCurrentJoystickGamepad &&
                     this->filterEventsForButtons)
                 {
                     return;
@@ -209,7 +212,7 @@ void HotkeysDialog::on_MainDialog_SdlEvent(SDL_Event* event)
 
             if (event->type == SDL_EVENT_GAMEPAD_AXIS_MOTION)
             { // gamepad axis
-                if (!this->isCurrentJoystickGameController &&
+                if (!this->isCurrentJoystickGamepad &&
                     this->filterEventsForButtons)
                 {
                     return;
@@ -219,12 +222,12 @@ void HotkeysDialog::on_MainDialog_SdlEvent(SDL_Event* event)
                 inputType = InputType::GamepadAxis;
                 sdlAxis = event->gaxis.axis;
                 sdlAxisValue = event->gaxis.value;
-                sdlAxisName = SDL_GetGamepadStringForAxis((SDL_GamepadAxis)sdlAxis);
+                sdlAxisName = SDL_GetGamepadStringForAxis(static_cast<SDL_GamepadAxis>(sdlAxis));
                 sdlAxisName += sdlAxisValue > 0 ? "+" : "-";
             }
             else
             { // joystick axis
-                if (this->isCurrentJoystickGameController &&
+                if (this->isCurrentJoystickGamepad &&
                     this->filterEventsForButtons)
                 {
                     return;
