@@ -13,6 +13,7 @@
 #include "common.hpp"
 #include <QDialog>
 
+#include "Utilities/InputProfileDB.hpp"
 #include "Widget/ControllerWidget.hpp"
 #include "Thread/SDLThread.hpp"
 #include "EventFilter.hpp"
@@ -31,19 +32,22 @@ private:
     QTimer* inputPollTimer;
     Thread::SDLThread* sdlThread;
 
+    Utilities::InputProfileDB inputProfileDB;
+
     QList<InputDevice> oldInputDeviceList;
     QList<InputDevice> inputDeviceList;
     bool updatingDeviceList = false;
 
     QList<Widget::ControllerWidget*> controllerWidgets;
-    SDL_Joystick* currentJoystick         = nullptr;
-    SDL_Gamepad* currentController = nullptr;
+    SDL_Joystick* currentJoystick = nullptr;
+    SDL_Gamepad* currentGamepad = nullptr;
     InputDevice currentDevice;
 
     int previousTabWidgetIndex = 0;
 
     EventFilter* eventFilter;
 
+    void addInputDevice(Widget::ControllerWidget* controllerWidget, const InputDevice& device);
     void addInputDevice(const InputDevice& device);
     void removeInputDevice(const InputDevice& device);
 
