@@ -111,10 +111,7 @@ NetplaySessionBrowserDialog::NetplaySessionBrowserDialog(QWidget *parent, QWebSo
         connect(networkAccessManager, &QNetworkAccessManager::finished, this, &NetplaySessionBrowserDialog::on_dispatcherRegionListDownload_Finished);
         networkAccessManager->setTransferTimeout(15000);
 
-        QNetworkRequest networkRequest(QUrl(this->dispatcherUrl + "/getRegions"));
-        networkRequest.setRawHeader("netplay-id", "RMG");
-
-        networkAccessManager->get(networkRequest);
+        networkAccessManager->get(NetplayCommon::GetNetworkRequest(this->dispatcherUrl + "/getRegions"));
     }
 
     this->validateJoinButton();
@@ -198,7 +195,7 @@ void NetplaySessionBrowserDialog::validateJoinButton(void)
     joinButton->setEnabled(this->validate());
 }
 
-void NetplaySessionBrowserDialog::toggleUI(bool enable, bool enableJoinButton)
+void NetplaySessionBrowserDialog::toggleUI(bool enable, bool enableJoinButton, bool toggleOtherUI)
 {
     QPushButton* joinButton = this->buttonBox->button(QDialogButtonBox::Ok);
     joinButton->setEnabled(enableJoinButton);
@@ -206,19 +203,17 @@ void NetplaySessionBrowserDialog::toggleUI(bool enable, bool enableJoinButton)
     QPushButton* refreshButton = this->buttonBox->button(QDialogButtonBox::RestoreDefaults);
     refreshButton->setEnabled(enable);
 
-    this->serverComboBox->setEnabled(enable);
-    this->nickNameLineEdit->setReadOnly(!enable);
+    if (toggleOtherUI)
+    {
+        this->serverComboBox->setEnabled(enable);
+        this->nickNameLineEdit->setReadOnly(!enable);
+    }
 }
 
 void NetplaySessionBrowserDialog::refreshSessions(void)
 {
-    // disable refresh button while refreshing
-    QPushButton* refreshButton = this->buttonBox->button(QDialogButtonBox::RestoreDefaults);
-    refreshButton->setEnabled(false);
-
-    // disable join button while refreshing
-    QPushButton* joinButton = this->buttonBox->button(QDialogButtonBox::Ok);
-    joinButton->setEnabled(false);
+    // disable join and refresh button while refreshing
+    this->toggleUI(false, false, false);
 
     if (NetplayCommon::IsServerDispatcher(this->serverComboBox))
     {
@@ -515,14 +510,14 @@ void NetplaySessionBrowserDialog::on_dispatcherRetrieveServers_Finished(QNetwork
 
 void NetplaySessionBrowserDialog::on_serverComboBox_currentIndexChanged(int index)
 {
-    QPushButton* refreshButton = this->buttonBox->button(QDialogButtonBox::RestoreDefaults);
-    refreshButton->setEnabled(index != -1);
-
     if (index == -1)
     {
         return;
     }
 
+    // disable join and refresh button while refreshing
+    this->toggleUI(false, false, false);
+
     bool dispatcher = NetplayCommon::IsServerDispatcher(this->serverComboBox, index);
 
     if (this->pingTimerId != -1)
@@ -545,8 +540,7 @@ void NetplaySessionBrowserDialog::on_serverComboBox_currentIndexChanged(int inde
         urlQuery.addQueryItem("region", region);
         url.setQuery(urlQuery);
 
-        QNetworkRequest networkRequest(url);
-        networkRequest.setRawHeader("netplay-id", "RMG");
+        QNetworkRequest networkRequest = NetplayCommon::GetNetworkRequest(url);
 
         // sadly we have to force HTTP/1 here due to a Qt bug,
         // we abort the connection which sadly in Qt6 causes an error and eventually segfault,
