@@ -24,13 +24,13 @@ bool EventFilter::eventFilter(QObject *object, QEvent *event)
     switch (event->type())
     {
     case QEvent::Type::KeyPress:
-        emit this->on_EventFilter_KeyPressed((QKeyEvent *)event);
+        emit this->on_EventFilter_KeyPressed(static_cast<QKeyEvent*>(event));
         return true;
     case QEvent::Type::Drop:
-        emit this->on_EventFilter_FileDropped((QDropEvent *)event);
+        emit this->on_EventFilter_FileDropped(static_cast<QDropEvent*>(event));
         return true;
     case QEvent::Type::KeyRelease:
-        emit this->on_EventFilter_KeyReleased((QKeyEvent *)event);
+        emit this->on_EventFilter_KeyReleased(static_cast<QKeyEvent*>(event));
         return true;
     default:
         break;
