@@ -171,7 +171,8 @@ void MainWindow::closeEvent(QCloseEvent *event)
 {
     bool inEmulation = this->emulationThread->isRunning();
 
-    if (!this->ui_ForceClose &&
+    if (this->ui_ShowUI &&
+        !this->ui_ForceClose &&
         inEmulation &&
         CoreSettingsGetBoolValue(SettingsID::GUI_ConfirmExitWhileInGame))
     {
@@ -200,9 +201,16 @@ void MainWindow::closeEvent(QCloseEvent *event)
     Qt::ToolBarArea toolbarArea = this->toolBarArea(this->toolBar);
     CoreSettingsSetValue(SettingsID::GUI_ToolbarArea, this->getToolbarSettingAreaFromArea(toolbarArea));
 
+    // attempt to shutdown emulation
     this->ui_NoSwitchToRomBrowser = true;
     this->on_Action_System_Shutdown();
 
+    // wait until emulation has shut down
+    while (this->emulationThread->isRunning())
+    {
+        QCoreApplication::processEvents();
+    }
+
     this->ui_Widget_RomBrowser->StopRefreshRomList();
 
     this->coreCallBacks->Stop();
@@ -214,13 +222,6 @@ void MainWindow::closeEvent(QCloseEvent *event)
     }
 #endif // NETPLAY
 
-    this->logDialog.close();
-
-    while (this->emulationThread->isRunning())
-    {
-        QCoreApplication::processEvents();
-    }
-
     CoreSettingsSave();
     CoreShutdown();
 
@@ -1489,13 +1490,15 @@ void MainWindow::on_EventFilter_FileDropped(QDropEvent *event)
 
     if (inEmulation && confirmDragDrop)
     {
-        QMessageBox::StandardButton reply = QMessageBox::question(this, "",
-            "Are you sure you want to launch the drag & dropped ROM?",
-            QMessageBox::Yes | QMessageBox::No);
-        if (reply == QMessageBox::No)
+        confirmDragDrop = false;
+        bool ret = QtMessageBox::Question(this, "Are you sure you want to launch the drag & dropped ROM?", 
+                                                "Don't ask for confirmation again", confirmDragDrop);
+        if (!ret)
         {
             return;
         }
+
+        CoreSettingsSetValue(SettingsID::GUI_ConfirmDragDrop, !confirmDragDrop);
     }
 
     file = urls.first().toLocalFile();
